@@ -18,8 +18,12 @@ class ShapeMapInstanceTracker(AbstractInstanceTracker):
         return self._instances_dict
 
     def _solve_targets_of_an_item(self, an_item):
-        self._instances_dict[an_item.shape_label] = an_item.node_selector.get_target_nodes()
+        for a_node in an_item.node_selector.get_target_nodes():
+            if a_node not in self._instances_dict:
+                self._instances_dict[a_node] = []
+            self._instances_dict[a_node].append(an_item.shape_label)
+        # self._instances_dict[an_item.shape_label] = an_item.node_selector.get_target_nodes()
 
-    @property
-    def disambiguator_prefix(self):
-        return "custom_"
\ No newline at end of file
+
+    def _specific_disambiguator_prefix(self):
+        return "custom_"
